Low level wrapper around the low level Cpp function for optimization purposes

hr_cost(par, obs, data, resolution, names)

Arguments

par

A list containing model calibration settings

obs

reference observations, a track file generated by {hr_xy()}

data

input data array

resolution

resolution of the underlying driver data

names

names of the parameters

Value

log-likelihood values given a data and parameter set

Details

The input assumes regularized data using hr_regularize() for both the spatial grid and the observed tracks.