This is the main function that handles the calibration of the home_range_cpp() C++ function through hr_cost().

hr_fit(data, obs, par, optim_out = TRUE, parallel = FALSE, verbose = FALSE)

Arguments

data

A data frame with driver data.

obs

reference observations (path) to a track file generated by {hr_xy()} or any data frame with the following columns: id, x, y

par

A list containing model calibration settings.

optim_out

A logical indicating whether the function returns the raw output of the optimization functions (defaults to TRUE).

parallel

enable parallel processing (default = FALSE, if TRUE or the number of desired cores to use in processing).

verbose

provide feedback on the command line (default = FALSE)

Value

A named list containing the calibrated parameter vector par and the output object from the optimization mod. For more details on this output and how to evaluate it, see runMCMC (also this post)