Regularizes spatial input data to a common equal area grid. It also performs sanity checks on the inputs to check if observations cover the spatial grid and returns the

hr_regularize(data, obs, crs = "EPSG:3035")

Arguments

data

raster stack with geospatial input data

obs

observed locations track

crs

an equal area CRS projection reference (default = EPSG:3035, or extended LAEA Europe)

Value

nested list with the regularized data and observed track, also saves the used projection crs