hr_cost.RdLow level wrapper around the low level Cpp function for optimization purposes
hr_cost(par, obs, data, resolution, names)log-likelihood values given a data and parameter set
The input assumes regularized data using hr_regularize() for both the spatial grid and the observed tracks.