Wrapper around the low level Cpp function, avoids some of the sanity checks of hr_run() thereby saving time during optimization.

hr_cost(par, obs, data, names)

Arguments

par

parameters

obs

reference observations

data

driver matrix

names

names of the parameters

Value

log likelihood values given a data and parameter set

Details

The input assumes regularized data using hr_regularize() for both the spatial grid and the observed tracks.