hr_fit.RdThis is the main function that handles the calibration of the home_range_cpp() C++ function through hr_cost().
hr_fit(data, obs, par, optim_out = TRUE, parallel = FALSE, verbose = FALSE)A data frame with driver data.
reference observations (path) to a track file generated by {hr_xy()} or any data frame with the following columns: id, x, y
A list containing model calibration settings.
A logical indicating whether the function returns the raw output of the optimization functions (defaults to TRUE).
enable parallel processing (default = FALSE, if TRUE or the number of desired cores to use in processing).
provide feedback on the command line (default = FALSE)