This is the main function that handles the calibration of the home_range_cpp() C++ function through hr_cost().

hr_fit(drivers, obs, settings, optim_out = TRUE, parallel = FALSE, ...)

Arguments

drivers

A data frame with driver data.

obs

A data frame containing observational data used for model calibration.

settings

A list containing model calibration settings.

optim_out

A logical indicating whether the function returns the raw output of the optimization functions (defaults to TRUE).

parallel

support parallel processing

...

Optional arguments passed on to the cost function specified as settings$metric.

Value

A named list containing the calibrated parameter vector par and the output object from the optimization mod. For more details on this output and how to evaluate it, see runMCMC (also this post)