hr_fit.RdThis is the main function that handles the calibration of the home_range_cpp() C++ function through hr_cost().
hr_fit(drivers, obs, settings, optim_out = TRUE, parallel = FALSE, ...)A data frame with driver data.
A data frame containing observational data used for model calibration.
A list containing model calibration settings.
A logical indicating whether the function returns the raw output of the optimization functions (defaults to TRUE).
support parallel processing
Optional arguments passed on to the cost function specified as
settings$metric.