hr_predict.RdThis is the main function to predict values from a fit set of parameters.
hr_predict(
data,
par,
obs,
steps = 1,
runs = 1,
keep_start = TRUE,
optimization = FALSE,
verbose = TRUE
)A data frame with driver data.
model parameters
reference observations (path) to a track file generated by {hr_xy()} or any data frame with the following columns: id, x, y
number of steps to simulate
number of runs to simulate
keep the starting position in the output data (this is run 0 and only has one coordinate, the release point)
optimization trigger (only used in debugging, set to FALSE)
provide feedback on the command line (default = TRUE)
simulated track