hr_raster_maps.RdThis downloads the basic raster maps covering your track, including a buffer zone to account for ranging behaviour. Note that this does not take care of data conversions or data harmoization.
biologging track with coordinates in lat lon (sf object)
downloads settings, data frame specifying data products and their target year and assets on the planetary computer STAC
buffer (in km, default = 20) around the biologging track file to accommodate for a sufficiently large home range area. Value should be adjusted to the target species.
output path
overwrite / and re-download the data
raster maps covering your area of interest as geotiff
This function does not leverage cloud optimized geotiffs via GDAL's vsicurl options due to the inconsistency in the deployment across the STAC. Therefore tiled data is downloaded which comes at a slight data volume penalty in favour of the stability across data products.
Please consult the Planetary computer data repository for information on the STAC product collection name, the required year and the asset (subset) required.