hr_regularize.RdRegularizes spatial input data to a common equal area grid. It also performs sanity checks on the inputs to check if observations cover the spatial grid and returns the
hr_regularize(data, obs, crs = "EPSG:3035")nested list with the regularized data and observed track, also saves the used projection crs