hr_xy.RdConverts map and track coordinates to col/row (X/Y), relative values with respect to the provided map. This is an internal function to interface with the C++ code which is not georeferenced internally. Note that you will need to use an equal area projection for best performance. For small areas lon/lat (WGS84) can be used but is not encouraged. The project should be chosen based on the locale.
hr_xy(map, track, method = "exact")the location of the track file in the correct format (written to the temporary directory)